/*******************************************************************************
* File Name: SSD1331_master.h
* Version 2.50
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the SPI Master Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SPIM_SSD1331_master_H)
#define CY_SPIM_SSD1331_master_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define SSD1331_master_INTERNAL_CLOCK             (0u)

#if(0u != SSD1331_master_INTERNAL_CLOCK)
    #include "SSD1331_master_IntClock.h"
#endif /* (0u != SSD1331_master_INTERNAL_CLOCK) */

#define SSD1331_master_MODE                       (4u)
#define SSD1331_master_DATA_WIDTH                 (8u)
#define SSD1331_master_MODE_USE_ZERO              (0u)
#define SSD1331_master_BIDIRECTIONAL_MODE         (1u)

/* Internal interrupt handling */
#define SSD1331_master_TX_BUFFER_SIZE             (4u)
#define SSD1331_master_RX_BUFFER_SIZE             (4u)
#define SSD1331_master_INTERNAL_TX_INT_ENABLED    (0u)
#define SSD1331_master_INTERNAL_RX_INT_ENABLED    (0u)

#define SSD1331_master_SINGLE_REG_SIZE            (8u)
#define SSD1331_master_USE_SECOND_DATAPATH        (SSD1331_master_DATA_WIDTH > SSD1331_master_SINGLE_REG_SIZE)

#define SSD1331_master_FIFO_SIZE                  (4u)
#define SSD1331_master_TX_SOFTWARE_BUF_ENABLED    ((0u != SSD1331_master_INTERNAL_TX_INT_ENABLED) && \
                                                     (SSD1331_master_TX_BUFFER_SIZE > SSD1331_master_FIFO_SIZE))

#define SSD1331_master_RX_SOFTWARE_BUF_ENABLED    ((0u != SSD1331_master_INTERNAL_RX_INT_ENABLED) && \
                                                     (SSD1331_master_RX_BUFFER_SIZE > SSD1331_master_FIFO_SIZE))


/***************************************
*        Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
    uint8 cntrPeriod;
} SSD1331_master_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  SSD1331_master_Init(void)                           ;
void  SSD1331_master_Enable(void)                         ;
void  SSD1331_master_Start(void)                          ;
void  SSD1331_master_Stop(void)                           ;

void  SSD1331_master_EnableTxInt(void)                    ;
void  SSD1331_master_EnableRxInt(void)                    ;
void  SSD1331_master_DisableTxInt(void)                   ;
void  SSD1331_master_DisableRxInt(void)                   ;

void  SSD1331_master_Sleep(void)                          ;
void  SSD1331_master_Wakeup(void)                         ;
void  SSD1331_master_SaveConfig(void)                     ;
void  SSD1331_master_RestoreConfig(void)                  ;

void  SSD1331_master_SetTxInterruptMode(uint8 intSrc)     ;
void  SSD1331_master_SetRxInterruptMode(uint8 intSrc)     ;
uint8 SSD1331_master_ReadTxStatus(void)                   ;
uint8 SSD1331_master_ReadRxStatus(void)                   ;
void  SSD1331_master_WriteTxData(uint8 txData)  \
                                                            ;
uint8 SSD1331_master_ReadRxData(void) \
                                                            ;
uint8 SSD1331_master_GetRxBufferSize(void)                ;
uint8 SSD1331_master_GetTxBufferSize(void)                ;
void  SSD1331_master_ClearRxBuffer(void)                  ;
void  SSD1331_master_ClearTxBuffer(void)                  ;
void  SSD1331_master_ClearFIFO(void)                              ;
void  SSD1331_master_PutArray(const uint8 buffer[], uint8 byteCount) \
                                                            ;

#if(0u != SSD1331_master_BIDIRECTIONAL_MODE)
    void  SSD1331_master_TxEnable(void)                   ;
    void  SSD1331_master_TxDisable(void)                  ;
#endif /* (0u != SSD1331_master_BIDIRECTIONAL_MODE) */

CY_ISR_PROTO(SSD1331_master_TX_ISR);
CY_ISR_PROTO(SSD1331_master_RX_ISR);


/***************************************
*   Variable with external linkage
***************************************/

extern uint8 SSD1331_master_initVar;


/***************************************
*           API Constants
***************************************/

#define SSD1331_master_TX_ISR_NUMBER     ((uint8) (SSD1331_master_TxInternalInterrupt__INTC_NUMBER))
#define SSD1331_master_RX_ISR_NUMBER     ((uint8) (SSD1331_master_RxInternalInterrupt__INTC_NUMBER))

#define SSD1331_master_TX_ISR_PRIORITY   ((uint8) (SSD1331_master_TxInternalInterrupt__INTC_PRIOR_NUM))
#define SSD1331_master_RX_ISR_PRIORITY   ((uint8) (SSD1331_master_RxInternalInterrupt__INTC_PRIOR_NUM))


/***************************************
*    Initial Parameter Constants
***************************************/

#define SSD1331_master_INT_ON_SPI_DONE    ((uint8) (0u   << SSD1331_master_STS_SPI_DONE_SHIFT))
#define SSD1331_master_INT_ON_TX_EMPTY    ((uint8) (0u   << SSD1331_master_STS_TX_FIFO_EMPTY_SHIFT))
#define SSD1331_master_INT_ON_TX_NOT_FULL ((uint8) (0u << \
                                                                           SSD1331_master_STS_TX_FIFO_NOT_FULL_SHIFT))
#define SSD1331_master_INT_ON_BYTE_COMP   ((uint8) (0u  << SSD1331_master_STS_BYTE_COMPLETE_SHIFT))
#define SSD1331_master_INT_ON_SPI_IDLE    ((uint8) (0u   << SSD1331_master_STS_SPI_IDLE_SHIFT))

/* Disable TX_NOT_FULL if software buffer is used */
#define SSD1331_master_INT_ON_TX_NOT_FULL_DEF ((SSD1331_master_TX_SOFTWARE_BUF_ENABLED) ? \
                                                                        (0u) : (SSD1331_master_INT_ON_TX_NOT_FULL))

/* TX interrupt mask */
#define SSD1331_master_TX_INIT_INTERRUPTS_MASK    (SSD1331_master_INT_ON_SPI_DONE  | \
                                                     SSD1331_master_INT_ON_TX_EMPTY  | \
                                                     SSD1331_master_INT_ON_TX_NOT_FULL_DEF | \
                                                     SSD1331_master_INT_ON_BYTE_COMP | \
                                                     SSD1331_master_INT_ON_SPI_IDLE)

#define SSD1331_master_INT_ON_RX_FULL         ((uint8) (0u << \
                                                                          SSD1331_master_STS_RX_FIFO_FULL_SHIFT))
#define SSD1331_master_INT_ON_RX_NOT_EMPTY    ((uint8) (0u << \
                                                                          SSD1331_master_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define SSD1331_master_INT_ON_RX_OVER         ((uint8) (0u << \
                                                                          SSD1331_master_STS_RX_FIFO_OVERRUN_SHIFT))

/* RX interrupt mask */
#define SSD1331_master_RX_INIT_INTERRUPTS_MASK    (SSD1331_master_INT_ON_RX_FULL      | \
                                                     SSD1331_master_INT_ON_RX_NOT_EMPTY | \
                                                     SSD1331_master_INT_ON_RX_OVER)
/* Nubmer of bits to receive/transmit */
#define SSD1331_master_BITCTR_INIT            (((uint8) (SSD1331_master_DATA_WIDTH << 1u)) - 1u)


/***************************************
*             Registers
***************************************/
#if(CY_PSOC3 || CY_PSOC5)
    #define SSD1331_master_TXDATA_REG (* (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F0_REG)
    #define SSD1331_master_TXDATA_PTR (  (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F0_REG)
    #define SSD1331_master_RXDATA_REG (* (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F1_REG)
    #define SSD1331_master_RXDATA_PTR (  (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F1_REG)
#else   /* PSOC4 */
    #if(SSD1331_master_USE_SECOND_DATAPATH)
        #define SSD1331_master_TXDATA_REG (* (reg16 *) \
                                          SSD1331_master_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define SSD1331_master_TXDATA_PTR (  (reg16 *) \
                                          SSD1331_master_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define SSD1331_master_RXDATA_REG (* (reg16 *) \
                                          SSD1331_master_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
        #define SSD1331_master_RXDATA_PTR (  (reg16 *) \
                                          SSD1331_master_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
    #else
        #define SSD1331_master_TXDATA_REG (* (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F0_REG)
        #define SSD1331_master_TXDATA_PTR (  (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F0_REG)
        #define SSD1331_master_RXDATA_REG (* (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F1_REG)
        #define SSD1331_master_RXDATA_PTR (  (reg8 *) \
                                                SSD1331_master_BSPIM_sR8_Dp_u0__F1_REG)
    #endif /* (SSD1331_master_USE_SECOND_DATAPATH) */
#endif     /* (CY_PSOC3 || CY_PSOC5) */

#define SSD1331_master_AUX_CONTROL_DP0_REG (* (reg8 *) \
                                        SSD1331_master_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)
#define SSD1331_master_AUX_CONTROL_DP0_PTR (  (reg8 *) \
                                        SSD1331_master_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)

#if(SSD1331_master_USE_SECOND_DATAPATH)
    #define SSD1331_master_AUX_CONTROL_DP1_REG  (* (reg8 *) \
                                        SSD1331_master_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
    #define SSD1331_master_AUX_CONTROL_DP1_PTR  (  (reg8 *) \
                                        SSD1331_master_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
#endif /* (SSD1331_master_USE_SECOND_DATAPATH) */

#define SSD1331_master_COUNTER_PERIOD_REG     (* (reg8 *) SSD1331_master_BSPIM_BitCounter__PERIOD_REG)
#define SSD1331_master_COUNTER_PERIOD_PTR     (  (reg8 *) SSD1331_master_BSPIM_BitCounter__PERIOD_REG)
#define SSD1331_master_COUNTER_CONTROL_REG    (* (reg8 *) SSD1331_master_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)
#define SSD1331_master_COUNTER_CONTROL_PTR    (  (reg8 *) SSD1331_master_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)

#define SSD1331_master_TX_STATUS_REG          (* (reg8 *) SSD1331_master_BSPIM_TxStsReg__STATUS_REG)
#define SSD1331_master_TX_STATUS_PTR          (  (reg8 *) SSD1331_master_BSPIM_TxStsReg__STATUS_REG)
#define SSD1331_master_RX_STATUS_REG          (* (reg8 *) SSD1331_master_BSPIM_RxStsReg__STATUS_REG)
#define SSD1331_master_RX_STATUS_PTR          (  (reg8 *) SSD1331_master_BSPIM_RxStsReg__STATUS_REG)

#define SSD1331_master_CONTROL_REG            (* (reg8 *) \
                                      SSD1331_master_BSPIM_BidirMode_CtrlReg__CONTROL_REG)
#define SSD1331_master_CONTROL_PTR            (  (reg8 *) \
                                      SSD1331_master_BSPIM_BidirMode_CtrlReg__CONTROL_REG)

#define SSD1331_master_TX_STATUS_MASK_REG     (* (reg8 *) SSD1331_master_BSPIM_TxStsReg__MASK_REG)
#define SSD1331_master_TX_STATUS_MASK_PTR     (  (reg8 *) SSD1331_master_BSPIM_TxStsReg__MASK_REG)
#define SSD1331_master_RX_STATUS_MASK_REG     (* (reg8 *) SSD1331_master_BSPIM_RxStsReg__MASK_REG)
#define SSD1331_master_RX_STATUS_MASK_PTR     (  (reg8 *) SSD1331_master_BSPIM_RxStsReg__MASK_REG)

#define SSD1331_master_TX_STATUS_ACTL_REG     (* (reg8 *) SSD1331_master_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define SSD1331_master_TX_STATUS_ACTL_PTR     (  (reg8 *) SSD1331_master_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define SSD1331_master_RX_STATUS_ACTL_REG     (* (reg8 *) SSD1331_master_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)
#define SSD1331_master_RX_STATUS_ACTL_PTR     (  (reg8 *) SSD1331_master_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)

#if(SSD1331_master_USE_SECOND_DATAPATH)
    #define SSD1331_master_AUX_CONTROLDP1     (SSD1331_master_AUX_CONTROL_DP1_REG)
#endif /* (SSD1331_master_USE_SECOND_DATAPATH) */


/***************************************
*       Register Constants
***************************************/

/* Status Register Definitions */
#define SSD1331_master_STS_SPI_DONE_SHIFT             (0x00u)
#define SSD1331_master_STS_TX_FIFO_EMPTY_SHIFT        (0x01u)
#define SSD1331_master_STS_TX_FIFO_NOT_FULL_SHIFT     (0x02u)
#define SSD1331_master_STS_BYTE_COMPLETE_SHIFT        (0x03u)
#define SSD1331_master_STS_SPI_IDLE_SHIFT             (0x04u)
#define SSD1331_master_STS_RX_FIFO_FULL_SHIFT         (0x04u)
#define SSD1331_master_STS_RX_FIFO_NOT_EMPTY_SHIFT    (0x05u)
#define SSD1331_master_STS_RX_FIFO_OVERRUN_SHIFT      (0x06u)

#define SSD1331_master_STS_SPI_DONE           ((uint8) (0x01u << SSD1331_master_STS_SPI_DONE_SHIFT))
#define SSD1331_master_STS_TX_FIFO_EMPTY      ((uint8) (0x01u << SSD1331_master_STS_TX_FIFO_EMPTY_SHIFT))
#define SSD1331_master_STS_TX_FIFO_NOT_FULL   ((uint8) (0x01u << SSD1331_master_STS_TX_FIFO_NOT_FULL_SHIFT))
#define SSD1331_master_STS_BYTE_COMPLETE      ((uint8) (0x01u << SSD1331_master_STS_BYTE_COMPLETE_SHIFT))
#define SSD1331_master_STS_SPI_IDLE           ((uint8) (0x01u << SSD1331_master_STS_SPI_IDLE_SHIFT))
#define SSD1331_master_STS_RX_FIFO_FULL       ((uint8) (0x01u << SSD1331_master_STS_RX_FIFO_FULL_SHIFT))
#define SSD1331_master_STS_RX_FIFO_NOT_EMPTY  ((uint8) (0x01u << SSD1331_master_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define SSD1331_master_STS_RX_FIFO_OVERRUN    ((uint8) (0x01u << SSD1331_master_STS_RX_FIFO_OVERRUN_SHIFT))

/* TX and RX masks for clear on read bits */
#define SSD1331_master_TX_STS_CLR_ON_RD_BYTES_MASK    (0x09u)
#define SSD1331_master_RX_STS_CLR_ON_RD_BYTES_MASK    (0x40u)

/* StatusI Register Interrupt Enable Control Bits */
/* As defined by the Register map for the AUX Control Register */
#define SSD1331_master_INT_ENABLE     (0x10u) /* Enable interrupt from statusi */
#define SSD1331_master_TX_FIFO_CLR    (0x01u) /* F0 - TX FIFO */
#define SSD1331_master_RX_FIFO_CLR    (0x02u) /* F1 - RX FIFO */
#define SSD1331_master_FIFO_CLR       (SSD1331_master_TX_FIFO_CLR | SSD1331_master_RX_FIFO_CLR)

/* Bit Counter (7-bit) Control Register Bit Definitions */
/* As defined by the Register map for the AUX Control Register */
#define SSD1331_master_CNTR_ENABLE    (0x20u) /* Enable CNT7 */

/* Bi-Directional mode control bit */
#define SSD1331_master_CTRL_TX_SIGNAL_EN  (0x01u)

/* Datapath Auxillary Control Register definitions */
#define SSD1331_master_AUX_CTRL_FIFO0_CLR         (0x01u)
#define SSD1331_master_AUX_CTRL_FIFO1_CLR         (0x02u)
#define SSD1331_master_AUX_CTRL_FIFO0_LVL         (0x04u)
#define SSD1331_master_AUX_CTRL_FIFO1_LVL         (0x08u)
#define SSD1331_master_STATUS_ACTL_INT_EN_MASK    (0x10u)

/* Component disabled */
#define SSD1331_master_DISABLED   (0u)


/***************************************
*       Macros
***************************************/

/* Returns true if componentn enabled */
#define SSD1331_master_IS_ENABLED (0u != (SSD1331_master_TX_STATUS_ACTL_REG & SSD1331_master_INT_ENABLE))

/* Retuns TX status register */
#define SSD1331_master_GET_STATUS_TX(swTxSts) ( (uint8)(SSD1331_master_TX_STATUS_REG | \
                                                          ((swTxSts) & SSD1331_master_TX_STS_CLR_ON_RD_BYTES_MASK)) )
/* Retuns RX status register */
#define SSD1331_master_GET_STATUS_RX(swRxSts) ( (uint8)(SSD1331_master_RX_STATUS_REG | \
                                                          ((swRxSts) & SSD1331_master_RX_STS_CLR_ON_RD_BYTES_MASK)) )


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define SSD1331_master_WriteByte   SSD1331_master_WriteTxData
#define SSD1331_master_ReadByte    SSD1331_master_ReadRxData
void  SSD1331_master_SetInterruptMode(uint8 intSrc)       ;
uint8 SSD1331_master_ReadStatus(void)                     ;
void  SSD1331_master_EnableInt(void)                      ;
void  SSD1331_master_DisableInt(void)                     ;

#define SSD1331_master_TXDATA                 (SSD1331_master_TXDATA_REG)
#define SSD1331_master_RXDATA                 (SSD1331_master_RXDATA_REG)
#define SSD1331_master_AUX_CONTROLDP0         (SSD1331_master_AUX_CONTROL_DP0_REG)
#define SSD1331_master_TXBUFFERREAD           (SSD1331_master_txBufferRead)
#define SSD1331_master_TXBUFFERWRITE          (SSD1331_master_txBufferWrite)
#define SSD1331_master_RXBUFFERREAD           (SSD1331_master_rxBufferRead)
#define SSD1331_master_RXBUFFERWRITE          (SSD1331_master_rxBufferWrite)

#define SSD1331_master_COUNTER_PERIOD         (SSD1331_master_COUNTER_PERIOD_REG)
#define SSD1331_master_COUNTER_CONTROL        (SSD1331_master_COUNTER_CONTROL_REG)
#define SSD1331_master_STATUS                 (SSD1331_master_TX_STATUS_REG)
#define SSD1331_master_CONTROL                (SSD1331_master_CONTROL_REG)
#define SSD1331_master_STATUS_MASK            (SSD1331_master_TX_STATUS_MASK_REG)
#define SSD1331_master_STATUS_ACTL            (SSD1331_master_TX_STATUS_ACTL_REG)

#define SSD1331_master_INIT_INTERRUPTS_MASK  (SSD1331_master_INT_ON_SPI_DONE     | \
                                                SSD1331_master_INT_ON_TX_EMPTY     | \
                                                SSD1331_master_INT_ON_TX_NOT_FULL_DEF  | \
                                                SSD1331_master_INT_ON_RX_FULL      | \
                                                SSD1331_master_INT_ON_RX_NOT_EMPTY | \
                                                SSD1331_master_INT_ON_RX_OVER      | \
                                                SSD1331_master_INT_ON_BYTE_COMP)
                                                
#define SSD1331_master_DataWidth                  (SSD1331_master_DATA_WIDTH)
#define SSD1331_master_InternalClockUsed          (SSD1331_master_INTERNAL_CLOCK)
#define SSD1331_master_InternalTxInterruptEnabled (SSD1331_master_INTERNAL_TX_INT_ENABLED)
#define SSD1331_master_InternalRxInterruptEnabled (SSD1331_master_INTERNAL_RX_INT_ENABLED)
#define SSD1331_master_ModeUseZero                (SSD1331_master_MODE_USE_ZERO)
#define SSD1331_master_BidirectionalMode          (SSD1331_master_BIDIRECTIONAL_MODE)
#define SSD1331_master_Mode                       (SSD1331_master_MODE)
#define SSD1331_master_DATAWIDHT                  (SSD1331_master_DATA_WIDTH)
#define SSD1331_master_InternalInterruptEnabled   (0u)

#define SSD1331_master_TXBUFFERSIZE   (SSD1331_master_TX_BUFFER_SIZE)
#define SSD1331_master_RXBUFFERSIZE   (SSD1331_master_RX_BUFFER_SIZE)

#define SSD1331_master_TXBUFFER       SSD1331_master_txBuffer
#define SSD1331_master_RXBUFFER       SSD1331_master_rxBuffer

#endif /* (CY_SPIM_SSD1331_master_H) */


/* [] END OF FILE */
