/*******************************************************************************
* File Name: SSD1331_master_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SSD1331_master_PVT.h"

static SSD1331_master_BACKUP_STRUCT SSD1331_master_backup =
{
    SSD1331_master_DISABLED,
    SSD1331_master_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SSD1331_master_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SSD1331_master_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SSD1331_master_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SSD1331_master_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SSD1331_master_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SSD1331_master_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SSD1331_master_Sleep(void) 
{
    /* Save components enable state */
    SSD1331_master_backup.enableState = ((uint8) SSD1331_master_IS_ENABLED);

    SSD1331_master_Stop();
}


/*******************************************************************************
* Function Name: SSD1331_master_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SSD1331_master_backup - used when non-retention registers are restored.
*  SSD1331_master_txBufferWrite - modified every function call - resets to
*  zero.
*  SSD1331_master_txBufferRead - modified every function call - resets to
*  zero.
*  SSD1331_master_rxBufferWrite - modified every function call - resets to
*  zero.
*  SSD1331_master_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SSD1331_master_Wakeup(void) 
{
    #if(SSD1331_master_RX_SOFTWARE_BUF_ENABLED)
        SSD1331_master_rxBufferFull  = 0u;
        SSD1331_master_rxBufferRead  = 0u;
        SSD1331_master_rxBufferWrite = 0u;
    #endif /* (SSD1331_master_RX_SOFTWARE_BUF_ENABLED) */

    #if(SSD1331_master_TX_SOFTWARE_BUF_ENABLED)
        SSD1331_master_txBufferFull  = 0u;
        SSD1331_master_txBufferRead  = 0u;
        SSD1331_master_txBufferWrite = 0u;
    #endif /* (SSD1331_master_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SSD1331_master_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SSD1331_master_backup.enableState)
    {
        SSD1331_master_Enable();
    }
}


/* [] END OF FILE */
