/* ========================================
 *
 * Copyright Oz-Fi audio®, 2020
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Oz-Fi audio®.
 *
 * ========================================
*/

/*************************
*       INCLUDES
**************************/
#include "SSD1331.h"


/*********************
 *      DEFINES
 *********************/
#define RST_HI      nRST_Write( 0b1 );
#define RST_LO      nRST_Write( 0b0 );
#define WRITE_CMD   DC_Write( 0b0 );
#define WRITE_DATA  DC_Write( 0b1 );
#define CS_LO       nCS_Write( 0b0 );
#define CS_HI       nCS_Write( 0b1 );
#define SOFTWARE_CS ( 0 )
/**********************
 *  STATIC PROTOTYPES
 **********************/
static void SSD1331_send_cmd( uint8 cmd );
static void SSD1331_send_data( uint8 data );


/************************
 *  FUNCTION DEFINITIONS
 ************************/
void lv_disp_init()
{
    CyDelay( 20 );
    CyDelay( 1 );
    RST_LO
    CyDelay( 10 );
    RST_HI
    CyDelay( 10 );
    SSD1331_send_cmd( DISPLAYOFF );
    SSD1331_send_cmd( REMAP_COLORDEPTH );
    SSD1331_send_cmd( 0x60 );                   /*  RGB color   */
    SSD1331_send_cmd( SET_STARTLINE );
    SSD1331_send_cmd( 0x00 );
    SSD1331_send_cmd( SET_OFFSET );
    SSD1331_send_cmd( 0x00 );
    SSD1331_send_cmd( SET_NORMALDISPLAYMODE );
    SSD1331_send_cmd( SET_MULTIPLEX );
    SSD1331_send_cmd( 0x3F );                   /*  1/64 duty   */
    SSD1331_send_cmd( SET_MASTERCONFIG );
    SSD1331_send_cmd( 0x8E );
    SSD1331_send_cmd( POWER_MODE );
    SSD1331_send_cmd( 0x0B );
    SSD1331_send_cmd( SET_PRECHARGE_LVL );
    SSD1331_send_cmd( 0x31 );
    SSD1331_send_cmd( DISP_CLK_DIVID );
    SSD1331_send_cmd( 0xF0 );                   /*  7:4 = Oscillator Frequency, 3:0 = CLK Div Ratio (A[3:0]+1 = 1..16)  */
    SSD1331_send_cmd( PRECHARGE_A );
    SSD1331_send_cmd( 0x64 );
    SSD1331_send_cmd( PRECHARGE_B );
    SSD1331_send_cmd( 0x78 );
    SSD1331_send_cmd( PRECHARGE_C );
    SSD1331_send_cmd( 0x64 );
    SSD1331_send_cmd( SET_PRECHARGE_LVL );
    SSD1331_send_cmd( 0x3A );
    SSD1331_send_cmd( SET_VCOM );
    SSD1331_send_cmd( 0x3E );
    SSD1331_send_cmd( MASTERCURRENTCONTROL );
    SSD1331_send_cmd( 0x06 );
    SSD1331_send_cmd( SET_A_CONTRAST );
    SSD1331_send_cmd( 0x91 );
    SSD1331_send_cmd( SET_B_CONTRAST );
    SSD1331_send_cmd( 0x50 );
    SSD1331_send_cmd( SET_C_CONTRAST );
    SSD1331_send_cmd( 0x7D );
    SSD1331_send_cmd( DEACTIVE_SCROLLING );
    SSD1331_send_cmd( DISPLAYON );
    CyDelay( 200 );
}

void flush_cb( lv_disp_drv_t * disp_drv, const lv_area_t * area, lv_color_t * color_p )
{
  int32 act_x1 = area -> x1 < 0 ? 0 : area -> x1;
  int32 act_x2 = area -> x2 > LV_HOR_RES_MAX -1 ? LV_HOR_RES_MAX - 1 : area -> x2;
  int32 act_y1 = area -> y1 < 0 ? 0 : area -> y1;
  int32 act_y2 = area -> y2 > LV_VER_RES_MAX -1 ? LV_VER_RES_MAX - 1 : area -> y2;
    
    /*  Set rectangle   */
  SSD1331_send_cmd( SET_COLUMN_ADDRESSES );
  SSD1331_send_cmd( act_x1 );
  SSD1331_send_cmd( act_x2 );

  SSD1331_send_cmd( SET_ROW_ADDRESSES );
  SSD1331_send_cmd( act_y1 );
  SSD1331_send_cmd( act_y2 );

  uint32 size = (act_x2 - act_x1 + 1) * (act_y2 - act_y1 + 1);
  for(uint32 i = 0; i < size; i++)
{
    SSD1331_send_data( *(uint16 *)color_p >> 8 );
    SSD1331_send_data( (uint8) *(uint16 *)color_p );
    color_p++;
}

  lv_disp_flush_ready( disp_drv );
}


/**********************
 *  STATIC FUNCTIONS
 **********************/

static void SSD1331_send_cmd( uint8 cmd )
{
 //   uint8 interruptStatus;
//    interruptStatus = CyEnterCriticalSection();
   #if SOFTWARE_CS 
   CS_LO 
   CyDelayUs( 1 );
   #endif 
   WRITE_CMD
   SSD1331_master_WriteTxData( cmd );
   while(!(SSD1331_master_ReadTxStatus() & SSD1331_master_STS_SPI_DONE));
   #if SOFTWARE_CS 
   CS_HI 
   #endif 
//CyExitCriticalSection( interruptStatus );
}


static void SSD1331_send_data( uint8 data )
{
//    uint8 interruptStatus;
//    interruptStatus = CyEnterCriticalSection();
    #if SOFTWARE_CS
    CS_LO
    CyDelayUs( 1 );
    #endif
    WRITE_DATA
    SSD1331_master_WriteTxData( data );
    while(!(SSD1331_master_ReadTxStatus() & SSD1331_master_STS_SPI_DONE));
    #if SOFTWARE_CS
    CS_HI
    #endif
//    CyExitCriticalSection( interruptStatus );
}
/*  [] END OF FILE  */